OC.L10N.register(
    "core",
    {
    "Please select a file." : "Por favor, seleccione un archivo.",
    "File is too big" : "El archivo es demasiado grande",
    "The selected file is not an image." : "El archivo seleccionado no es una imagen.",
    "The selected file cannot be read." : "El archivo seleccionado no puede ser leído.",
    "The file was uploaded" : "El archivo fue subido",
    "The uploaded file exceeds the upload_max_filesize directive in php.ini" : "El archivo subido excede la directiva upload_max_filesize del php.ini",
    "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "El archivo subido excede la directiva MAX_FILE_SIZE que fue especificada en el formulario HTML",
    "The file was only partially uploaded" : "El archivo fue subido parcialmente",
    "No file was uploaded" : "El archivo no fue subido",
    "Missing a temporary folder" : "Falta una carpeta temporal",
    "Could not write file to disk" : "No se pudo escribir el archivo en el disco",
    "A PHP extension stopped the file upload" : "Una extensión PHP detuvo la subida del archivo",
    "Invalid file provided" : "Archivo no válido",
    "No image or file provided" : "No se especificó ningún archivo o imagen",
    "Unknown filetype" : "Tipo de archivo desconocido",
    "An error occurred. Please contact your admin." : "Ha ocurrido un error. Póngase en contacto con su administrador.",
    "Invalid image" : "La imagen no es válida",
    "No temporary profile picture available, try again" : "No hay disponible una imagen temporal de perfil, pruebe de nuevo",
    "No crop data provided" : "No se han proporcionado datos del recorte",
    "No valid crop data provided" : "Recorte inválido",
    "Crop is not square" : "El recorte no es cuadrado",
    "State token does not match" : "El token dado no coincide",
    "Invalid app password" : "Contraseña de la app no válida",
    "Could not complete login" : "No se ha podido completar el inicio de sesión",
    "State token missing" : "No se encontró token de estado",
    "Your login token is invalid or has expired" : "Tu token de login no es válido o ha caducado",
    "This community release of Nextcloud is unsupported and push notifications are limited." : "Esta versión comunitaria de Nextcloud ya no está soportada y las notificaciones push están limitadas.",
    "Login" : "Iniciar sesión",
    "Unsupported email length (>255)" : "Longitud de correo electrónico no soportada (>255)",
    "Password reset is disabled" : "El restablecimiento de la contraseña está deshabilitado",
    "Could not reset password because the token is expired" : "No se puede restablecer la contraseña porque el token de autenticación ha caducado.",
    "Could not reset password because the token is invalid" : "No se puede restablecer la contraseña porque el token de autenticación no es válido.",
    "Password is too long. Maximum allowed length is 469 characters." : "La contraseña es muy larga. El tamaño máximo permitido es 469 caracteres.",
    "%s password reset" : "%s restablecer contraseña",
    "Password reset" : "Restablecer contraseña",
    "Click the following button to reset your password. If you have not requested the password reset, then ignore this email." : "Haz clic en el siguiente botón para restaurar tu contraseña. Si no has solicitado que se te restaure la contraseña, ignora este correo.",
    "Click the following link to reset your password. If you have not requested the password reset, then ignore this email." : "Haz clic en el siguiente enlace para restaurar tu contraseña. Si no has solicitado que se te restaure la contraseña, ignora este correo.",
    "Reset your password" : "Resetear su contraseña",
    "The given provider is not available" : "El proveedor indicado no está disponible",
    "Task not found" : "Tarea no encontrada",
    "Internal error" : "Error interno",
    "Not found" : "No encontrado",
    "Bad request" : "Solicitud errónea",
    "Requested task type does not exist" : "El tipo de tarea solicitada no existe",
    "Necessary language model provider is not available" : "El proveedor de modelo de lenguaje necesario no está disponible",
    "No text to image provider is available" : "No hay proveedores de texto a imagen disponible",
    "Image not found" : "Imagen no encontrada",
    "No translation provider available" : "No hay proveedores de traducción disponibles",
    "Could not detect language" : "No fue posible detectar el lenguaje",
    "Unable to translate" : "No es posible traducir",
    "Nextcloud Server" : "Servidor Nexcloud",
    "Some of your link shares have been removed" : "Algunos de tus enlaces compartidos han sido eliminados.",
    "Due to a security bug we had to remove some of your link shares. Please see the link for more information." : "Debido a un bug de seguridad hemos tenido que eliminar algunos de tus enlaces compartidos. Por favor, accede al link para más información.",
    "The account limit of this instance is reached." : "Se alcanzó el límite de cuentas de esta instancia.",
    "Enter your subscription key in the support app in order to increase the account limit. This does also grant you all additional benefits that Nextcloud Enterprise offers and is highly recommended for the operation in companies." : "Ingrese su clave de suscripción en la aplicación de soporte para aumentar el límite de cuentas. Esto también le otorga todos los beneficios adicionales que ofrece Nextcloud Enterprise y que es altamente recomendado para la operación en empresas.",
    "Learn more ↗" : "Saber más ↗",
    "Preparing update" : "Preparando la actualización",
    "[%d / %d]: %s" : "[%d / %d]: %s",
    "Repair step:" : "Paso de reparación:",
    "Repair info:" : "Información de reparación:",
    "Repair warning:" : "Advertencia de reparación:",
    "Repair error:" : "Error que reparar:",
    "Please use the command line updater because updating via browser is disabled in your config.php." : "Por favor, utilice el actualizador por línea de comandos ya que la actualización vía navegador se encuentra deshabilitado en su config.php",
    "Turned on maintenance mode" : "Modo mantenimiento activado",
    "Turned off maintenance mode" : "Modo mantenimiento desactivado",
    "Maintenance mode is kept active" : "El modo mantenimiento aún está activo.",
    "Updating database schema" : "Actualizando el esquema del base de datos",
    "Updated database" : "Base de datos actualizada",
    "Update app \"%s\" from App Store" : "Actualizar la app \"%s\" desde la App Store",
    "Checking whether the database schema for %s can be updated (this can take a long time depending on the database size)" : "Comprobar si se puede actualizar el esquema de la base de datos %s (esto puede tardar bastante tiempo, dependiendo del tamaño de la base de datos)",
    "Updated \"%1$s\" to %2$s" : "\"%1$s\" actualizado a %2$s",
    "Set log level to debug" : "Establecer el nivel de registro a depuración",
    "Reset log level" : "Restablecer el nivel de registro",
    "Starting code integrity check" : "Comenzando comprobación de integridad de código",
    "Finished code integrity check" : "Terminada la comprobación de integridad de código",
    "%s (incompatible)" : "%s (incompatible)",
    "The following apps have been disabled: %s" : "Las siguientes apps han sido desactivadas: %s",
    "Already up to date" : "Ya actualizado",
    "Error occurred while checking server setup" : "Ha ocurrido un error al revisar la configuración del servidor",
    "For more details see the {linkstart}documentation ↗{linkend}." : "Para más detalles compruebe la {linkstart}documentación ↗{linkend}.",
    "unknown text" : "texto desconocido",
    "Hello world!" : "¡Hola, mundo!",
    "sunny" : "soleado",
    "Hello {name}, the weather is {weather}" : "Hola {name}, el día es {weather}",
    "Hello {name}" : "Hola {name}",
    "<strong>These are your search results<script>alert(1)</script></strong>" : "<strong>Estos son sus resultados de búsqueda<script>alert(1)</script></strong>",
    "new" : "Nuevo",
    "_download %n file_::_download %n files_" : ["descargar %n archivos","descargar %n archivos","descargar %n archivos"],
    "The update is in progress, leaving this page might interrupt the process in some environments." : "La actualización está en curso, salir de esta página podrían interrumpir el proceso en algunos entornos.",
    "Update to {version}" : "Actualice a {version}",
    "An error occurred." : "Ocurrió un error.",
    "Please reload the page." : "Recargue/Actualice la página",
    "The update was unsuccessful. For more information <a href=\"{url}\">check our forum post</a> covering this issue." : "La actualización tuvo un problema. Para más información <a href=\"{url}\">consulta nuestro artículo del foro</a> cubriendo este tema.",
    "The update was unsuccessful. Please report this issue to the <a href=\"https://github.com/nextcloud/server/issues\" target=\"_blank\">Nextcloud community</a>." : "La actualización ha fallado. Por favor, informa de este problema a la  <a href=\"https://github.com/nextcloud/server/issues\" target=\"_blank\">comunidad de Nextcloud</a>.",
    "Continue to {productName}" : "Continuar a {productName}",
    "_The update was successful. Redirecting you to {productName} in %n second._::_The update was successful. Redirecting you to {productName} in %n seconds._" : ["La actualización ha terminado con éxito. Redirigiendo a su {productName} en %n segundo. ","La actualización ha terminado con éxito. Redirigiendo a su {productName} en %n segundos. ","La actualización ha terminado con éxito. Redirigiendo a su {productName} en %n segundos. "],
    "Applications menu" : "Menú Aplicaciones",
    "Apps" : "Aplicaciones",
    "More apps" : "Más aplicaciones",
    "_{count} notification_::_{count} notifications_" : ["{count} notificación","{count} notificaciones","{count} notificaciones"],
    "No" : "No",
    "Yes" : "Sí",
    "The remote URL must include the user." : "La URL remota debe incluir el usuario.",
    "Invalid remote URL." : "URL remota inválida.",
    "Failed to add the public link to your Nextcloud" : "No se ha podido añadir el enlace público a tu Nextcloud",
    "Federated user" : "Usuario federado",
    "user@your-nextcloud.org" : "usuario@su-nextcloud.org",
    "Create share" : "Crear un recurso compartido",
    "Direct link copied to clipboard" : "Enlace directo copiado al portapapeles",
    "Please copy the link manually:" : "Por favor, copie el enlace manualmente:",
    "Custom date range" : "Rango de fechas personalizado",
    "Pick start date" : "Escoja una fecha de inicio",
    "Pick end date" : "Escoja una fecha fin",
    "Search in date range" : "Buscar en un rango de fechas",
    "Search in current app" : "Buscar en la app actual",
    "Clear search" : "Limpiar búsqueda",
    "Search everywhere" : "Buscar en todas partes",
    "Searching …" : "Buscando  …",
    "Start typing to search" : "Empieza a escribir para buscar",
    "No matching results" : "No hay coincidencias",
    "Today" : "Hoy",
    "Last 7 days" : "Últimos 7 días",
    "Last 30 days" : "Últimos 30 días",
    "This year" : "Este año",
    "Last year" : "El año pasado año",
    "Unified search" : "Búsqueda unificada",
    "Search apps, files, tags, messages" : "Buscar en apps, archivos, etiquetas, mensajes",
    "Places" : "Ubicaciones",
    "Date" : "Fecha",
    "Search people" : "Buscar personas",
    "People" : "Personas",
    "Filter in current view" : "Filtrar en la vista actual",
    "Results" : "Resultados",
    "Load more results" : "Cargar más resultados",
    "Search in" : "Buscar en",
    "Log in" : "Iniciar sesión",
    "Logging in …" : "Iniciando sesión ...",
    "Log in to {productName}" : "Iniciar sesión en {productName}",
    "Wrong login or password." : "Nombre de usuario o contraseña incorrecto.",
    "This account is disabled" : "Esta cuenta está deshabilitada",
    "We have detected multiple invalid login attempts from your IP. Therefore your next login is throttled up to 30 seconds." : "Hemos detectado múltiples intentos inválidos desde tu IP. Por tanto, tu próximo intento se retrasará 30 segundos.",
    "Account name or email" : "Nombre de cuenta o correo electrónico",
    "Account name" : "Nombre de cuenta",
    "Server side authentication failed!" : "La autenticación ha fallado en el servidor.",
    "Please contact your administrator." : "Por favor, contacte con el administrador.",
    "Temporary error" : "Error temporal",
    "Please try again." : "Por favor, inténtelo de nuevo.",
    "An internal error occurred." : "Ha habido un error interno.",
    "Please try again or contact your administrator." : "Por favor reintente nuevamente o contáctese con su administrador.",
    "Password" : "Contraseña",
    "Log in with a device" : "Iniciar sesión con dispositivo",
    "Login or email" : "Nombre de usuario o correo electrónico",
    "Your account is not setup for passwordless login." : "Tu cuenta no está configurada para iniciar de sesión sin contraseña",
    "Your connection is not secure" : "Tu conexión no es segura",
    "Passwordless authentication is only available over a secure connection." : "La autenticación sin contraseña solo está disponible bajo una conexión segura.",
    "Browser not supported" : "Navegador no compatible",
    "Passwordless authentication is not supported in your browser." : "La autenticación sin contraseña no está soportada en tu navegador.",
    "Reset password" : "Restablecer contraseña",
    "Back to login" : "Volver a la identificación",
    "If this account exists, a password reset message has been sent to its email address. If you do not receive it, verify your email address and/or Login, check your spam/junk folders or ask your local administration for help." : "Si la cuenta existe, se ha enviado un mensaje para reestablecer la contraseña a su dirección de correo. Si no lo recibe, verifique su dirección de correo y/o su nombre de cuenta, compruebe también sus carpetas de Spam/Correo basura o solicite ayuda a su administrador.",
    "Couldn't send reset email. Please contact your administrator." : "No pudo enviarse el correo para restablecer la contraseña. Por favor, contacte con su administrador.",
    "Password cannot be changed. Please contact your administrator." : "La contraseña no puede ser cambiada. Por favor, contacte con su administrador.",
    "New password" : "Nueva contraseña",
    "Your files are encrypted. There will be no way to get your data back after your password is reset. If you are not sure what to do, please contact your administrator before you continue. Do you really want to continue?" : "Tus archivos están encriptados. No habrá forma de recuperar sus datos después de restablecer su contraseña. Si no está seguro de qué hacer, comuníquese con su administrador antes de continuar. ¿De verdad quieres continuar?",
    "I know what I'm doing" : "Sé lo que estoy haciendo",
    "Resetting password" : "Restableciendo contraseña",
    "Schedule work & meetings, synced with all your devices." : "Programe trabajo y reuniones, sincronizados con todos sus dispositivos.",
    "Keep your colleagues and friends in one place without leaking their private info." : "Mantenga a sus colegas y amigos en un sólo sitio sin dejar escapar su información privada.",
    "Simple email app nicely integrated with Files, Contacts and Calendar." : "Simple email app se integra bien con Archivos, Contactos y Calendario.",
    "Chatting, video calls, screen sharing, online meetings and web conferencing – in your browser and with mobile apps." : "Mensajes, videollamadas, compartir pantalla, reuniones en línea y conferencias web – en su navegador y aplicaciones móviles.",
    "Collaborative documents, spreadsheets and presentations, built on Collabora Online." : "Documentos colaborativos, hojas de cálculo y presentaciones, basadas en Collabora Online.",
    "Distraction free note taking app." : "App de de notas y escritura libre de distracciones.",
    "Recommended apps" : "Aplicaciones recomendadas",
    "Loading apps …" : "Cargando apps ...",
    "Could not fetch list of apps from the App Store." : "No es posible obtener la lista de apps de la App Store.",
    "App download or installation failed" : "Falló la descarga o instalación de la App",
    "Cannot install this app because it is not compatible" : "No se puede instalar esta app porque no es compatible.",
    "Cannot install this app" : "No se puede instalar esta app",
    "Skip" : "Saltar",
    "Installing apps …" : "Instalando apps ...",
    "Install recommended apps" : "Instalar las aplicaciones recomendadas",
    "Avatar of {displayName}" : "Avatar de {displayName}",
    "Settings menu" : "Menú de configuraciones",
    "Loading your contacts …" : "Cargando tus contactos...",
    "Looking for {term} …" : "Buscando {term}...",
    "Search contacts" : "Buscar contactos",
    "Reset search" : "Resetear búsqueda",
    "Search contacts …" : "Buscar contactos...",
    "Could not load your contacts" : "No se han podido cargar los contactos",
    "No contacts found" : "No se han encontrado contactos",
    "Show all contacts" : "Mostrar todos los contactos",
    "Install the Contacts app" : "Instala la aplicación Contactos",
    "Search" : "Buscar",
    "No results for {query}" : "Sin resultados para {query}",
    "Press Enter to start searching" : "Pulse Enter para iniciar la búsqueda",
    "_Please enter {minSearchLength} character or more to search_::_Please enter {minSearchLength} characters or more to search_" : ["Por favor, introduce {minSearchLength} carácter o más para buscar","Por favor, introduce {minSearchLength} caracteres o más para buscar","Por favor, introduce {minSearchLength} caracteres o más para buscar"],
    "An error occurred while searching for {type}" : "Ha ocurrido un error al buscar {type}",
    "Search starts once you start typing and results may be reached with the arrow keys" : "La búsqueda empieza una vez que comienza a escribir y los resultados pueden seleccionarse con las teclas de flecha",
    "Search for {name} only" : "Buscar solo por {name}",
    "Loading more results …" : "Cargando más resultados …",
    "Forgot password?" : "¿Contraseña olvidada?",
    "Back to login form" : "Volver al formulario de inicio de sesión",
    "Back" : "Atrás",
    "Login form is disabled." : "La página de inicio de sesión está deshabilitada.",
    "The Nextcloud login form is disabled. Use another login option if available or contact your administration." : "El formulario de inicio de sesión de Nextcloud está deshabilitado. Use otro medio de inicio de sesión disponible o contacte a su administración.",
    "More actions" : "Más acciones",
    "Security warning" : "Advertencia de seguridad",
    "Storage & database" : "Almacenamiento y base de datos",
    "Data folder" : "Carpeta de datos",
    "Install and activate additional PHP modules to choose other database types." : "Instalar y activar módulos PHP adicionales para elegir otros formatos de base de datos.",
    "For more details check out the documentation." : "Para más detalles revisar la documentación.",
    "Performance warning" : "Advertencia de rendimiento",
    "You chose SQLite as database." : "Has elegido SQLite como base de datos.",
    "SQLite should only be used for minimal and development instances. For production we recommend a different database backend." : "SQLite solo debería usarse para instancias mínimas y de desarrollo. Para producción recomendamos un motor de bases de datos diferente.",
    "If you use clients for file syncing, the use of SQLite is highly discouraged." : "Si usas clientes para sincronizar archivos, el uso del SQLite está muy desaconsejado.",
    "Database user" : "Usuario de la base de datos",
    "Database password" : "Contraseña de la base de datos",
    "Database name" : "Nombre de la base de datos",
    "Database tablespace" : "Espacio de tablas de la base de datos",
    "Please specify the port number along with the host name (e.g., localhost:5432)." : "Por favor especifique el numero del puerto junto al nombre del host (p.e., localhost:5432).",
    "Database host" : "Host de la base de datos",
    "Installing …" : "Instalando …",
    "Install" : "Instalar",
    "Need help?" : "¿Necesita ayuda?",
    "See the documentation" : "Vea la documentación",
    "{name} version {version} and above" : "{name} versión {version} y superior",
    "This browser is not supported" : "Este navegador no está soportado",
    "Your browser is not supported. Please upgrade to a newer version or a supported one." : "Su navegador no está soportado. Por favor actualice a una versión nueva o a uno soportado.",
    "Continue with this unsupported browser" : "Continuar con este navegador no soportado",
    "Supported versions" : "Versiones soportadas",
    "Search {types} …" : "Buscar {types}…",
    "Choose {file}" : "Seleccionar {file}",
    "Choose" : "Seleccionar",
    "Copy to {target}" : "Copiar a {target}",
    "Copy" : "Copiar",
    "Move to {target}" : "Mover a {target}",
    "Move" : "Mover",
    "OK" : "OK",
    "read-only" : "solo lectura",
    "_{count} file conflict_::_{count} file conflicts_" : ["{count} conflicto de archivo","{count} conflictos de archivo","{count} conflictos de archivo"],
    "One file conflict" : "Un conflicto de archivo",
    "New Files" : "Nuevos archivos",
    "Already existing files" : "Archivos ya existentes",
    "Which files do you want to keep?" : "¿Qué archivos desea mantener?",
    "If you select both versions, the copied file will have a number added to its name." : "Si seleccionas ambas versiones, el archivo copiado tendrá añadido un número en su nombre.",
    "Cancel" : "Cancelar",
    "Continue" : "Continuar",
    "(all selected)" : "(seleccionados todos)",
    "({count} selected)" : "({count} seleccionados)",
    "Error loading file exists template" : "Error cargando plantilla de archivo existente",
    "Saving …" : "Guardando...",
    "seconds ago" : "hace segundos",
    "Connection to server lost" : "Se ha perdido la conexión al servidor",
    "_Problem loading page, reloading in %n second_::_Problem loading page, reloading in %n seconds_" : ["Problema al cargar la página, volverá a cargar en %n segundo","Problema al cagar la página, volverá a cargar en %n segundos","Problema al cagar la página, volverá a cargar en %n segundos"],
    "Add to a project" : "Añadir a un proyecto",
    "Show details" : "Mostrar detalles",
    "Hide details" : "Ocultar detalles",
    "Rename project" : "Renombrar proyecto",
    "Failed to rename the project" : "Fallo al renombrar el proyecto",
    "Failed to create a project" : "Fallo al crear el proyecto",
    "Failed to add the item to the project" : "Fallo al añadir el elemento al proyecto",
    "Connect items to a project to make them easier to find" : "Conecta elementos a un proyecto para encontrarlos fácilmente",
    "Type to search for existing projects" : "Escribe para buscar proyectos existentes",
    "New in" : "Nuevo en",
    "View changelog" : "Ver registro de cambios",
    "No action available" : "No hay acciones disponibles",
    "Error fetching contact actions" : "Error recuperando las acciones de los contactos",
    "Close \"{dialogTitle}\" dialog" : "Cerrar diálogo \"{dialogTitle}\"",
    "Email length is at max (255)" : "La longitud de correo electrónico está en su límite (255)",
    "Non-existing tag #{tag}" : "Categoría #{tag} no existente",
    "Restricted" : "Restringido",
    "Invisible" : "Invisible",
    "Delete" : "Eliminar",
    "Rename" : "Renombrar",
    "Collaborative tags" : "Etiquetas colaborativas",
    "No tags found" : "No se encontraron etiquetas",
    "Clipboard not available, please copy manually" : "Portapapeles no disponible, por favor copie manualmente",
    "Personal" : "Personal",
    "Accounts" : "Cuentas",
    "Admin" : "Administración",
    "Help" : "Ayuda",
    "Access forbidden" : "Acceso denegado",
    "Page not found" : "Página no encontrada",
    "The page could not be found on the server or you may not be allowed to view it." : "La página no fue encontrada en el servidor o podría no tener acceso para verla.",
    "Back to %s" : "Volver a %s",
    "Too many requests" : "Demasiadas peticiones",
    "There were too many requests from your network. Retry later or contact your administrator if this is an error." : "Hubo demasiadas peticiones desde su red. Vuelva a intentarlo más tarde o póngase en contacto con su administrador si se trata de un error.",
    "Error" : "Error",
    "Internal Server Error" : "Error interno del servidor",
    "The server was unable to complete your request." : "El servidor no ha podido completar tu petición.",
    "If this happens again, please send the technical details below to the server administrator." : "Si sucede de nuevo, por favor, envía los detalles técnicos a continuación al administrador del servidor.",
    "More details can be found in the server log." : "Pueden verse más detalles en el registro del servidor.",
    "For more details see the documentation ↗." : "Para más detalles, vea la documentación ↗.",
    "Technical details" : "Detalles técnicos",
    "Remote Address: %s" : "Dirección remota: %s",
    "Request ID: %s" : "ID de la solicitud: %s",
    "Type: %s" : "Tipo: %s",
    "Code: %s" : "Código: %s",
    "Message: %s" : "Mensaje: %s",
    "File: %s" : "Archivo: %s",
    "Line: %s" : "Línea: %s",
    "Trace" : "Trazas",
    "It looks like you are trying to reinstall your Nextcloud. However the file CAN_INSTALL is missing from your config directory. Please create the file CAN_INSTALL in your config folder to continue." : "Parece que estás intentando reinstalar Nextcloud. Sin embargo el archivo CAN_INSTALL no se encuentra en la carpeta config. Por favor, crea el archivo CAN_INSTALL en la carpeta config para continuar",
    "Could not remove CAN_INSTALL from the config folder. Please remove this file manually." : "No se puede eliminar el archivo CAN_INSTALL de la carpeta config. Por favor, eliminalo manualmente.",
    "This application requires JavaScript for correct operation. Please {linkstart}enable JavaScript{linkend} and reload the page." : "Esta aplicación requiere JavaScript para operar correctamente. Por favor, {linkstart}habilite JavaScript{linkend} y recargue la página.",
    "Skip to main content" : "Saltar al contenido principal",
    "Skip to navigation of app" : "Saltar a la navegación de la app",
    "Go to %s" : "Ir a %s",
    "Get your own free account" : "Consigue tu propia cuenta gratuita",
    "Connect to your account" : "Conectar a cuenta",
    "Please log in before granting %1$s access to your %2$s account." : "Por favor, inicia sesión antes de conceder a %1$s acceso a tu cuenta %2$s.",
    "If you are not trying to set up a new device or app, someone is trying to trick you into granting them access to your data. In this case do not proceed and instead contact your system administrator." : "Si no estás intentando añadir un nuevo dispositivo o una nueva app, alguien está intentando engañarte para que proporciones acceso a tus datos. En este caso, no prosigas y en su lugar avisa a tu administrador de sistemas.",
    "App password" : "Contraseña de aplicación",
    "Grant access" : "Conceder acceso",
    "Alternative log in using app password" : "Inicio de sesión alternativo usando la contraseña de la aplicación",
    "Account access" : "Acceso a la cuenta",
    "Currently logged in as %1$s (%2$s)." : "Actualmente está conectado como %1$s (%2$s).",
    "You are about to grant %1$s access to your %2$s account." : "Estás a punto de conceder a %1$s acceso a tu cuenta %2$s.",
    "Account connected" : "Cuenta conectada",
    "Your client should now be connected!" : "Tu cliente debería estar ahora conectado.",
    "You can close this window." : "Puedes cerrar esta ventana.",
    "Previous" : "Anterior",
    "This share is password-protected" : "Este recurso compartido está protegido por contraseña",
    "The password is wrong or expired. Please try again or request a new one." : "La contraseña está mal o ha caducado. Por favor, inténtalo de nuevo o solicita una nueva.",
    "Please type in your email address to request a temporary password" : "Escriba su dirección de correo electrónico para solicitar una contraseña temporal",
    "Email address" : "Dirección de correo",
    "Password sent!" : "¡Contraseña enviada!",
    "You are not authorized to request a password for this share" : "No está autorizado a solicitar una contraseña para este recurso compartido",
    "Two-factor authentication" : "Autenticación de dos factores",
    "Enhanced security is enabled for your account. Choose a second factor for authentication:" : "La seguridad mejorada está habilitada para su cuenta. Elija una segunda forma de autenticación:",
    "Could not load at least one of your enabled two-factor auth methods. Please contact your admin." : "No se pudo cargar al menos uno de sus métodos de autenticación de dos factores. Por favor, póngase en contacto con un administrador.",
    "Two-factor authentication is enforced but has not been configured on your account. Contact your admin for assistance." : "La autenticación de dos factores es obligatoria pero no se ha configurado en su cuenta. Póngase en contacto con su administrador para obtener ayuda.",
    "Two-factor authentication is enforced but has not been configured on your account. Please continue to setup two-factor authentication." : "La autenticación de dos factores es obligatoria pero no se ha configurado en tu cuenta. Por favor, continúa para configurar la autenticación de dos factores.",
    "Set up two-factor authentication" : "Configurar autenticación de dos factores",
    "Two-factor authentication is enforced but has not been configured on your account. Use one of your backup codes to log in or contact your admin for assistance." : "La autenticación de dos factores es obligatoria pero no se ha configurado en su cuenta. Use uno de sus códigos de respaldo para iniciar sesión o comuníquese con su administrador para obtener ayuda.",
    "Use backup code" : "Usar código de respaldo",
    "Cancel login" : "Cancelar inicio de sesión",
    "Enhanced security is enforced for your account. Choose which provider to set up:" : "Es obligatorio usar la seguridad mejorada en tu cuenta. Escoge qué proveedor configurar:",
    "Error while validating your second factor" : "Error al validar su segundo factor",
    "Access through untrusted domain" : "Acceso a través de un dominio del que no se confía",
    "Please contact your administrator. If you are an administrator, edit the \"trusted_domains\" setting in config/config.php like the example in config.sample.php." : "Por favor, ponte en contacto con tu administrador. Si eres un administrador, edita la configuración \"trusted_domains\" en config/config.php como en el ejemplo que aparece en config.sample.php.",
    "Further information how to configure this can be found in the %1$sdocumentation%2$s." : "Más información sobre cómo configurar esto se puede encontrar en la %1$sdocumentación%2$s.",
    "App update required" : "Es necesaria una actualización en la aplicación",
    "%1$s will be updated to version %2$s" : "%1$s se actualizará a la versión %2$s",
    "The following apps will be updated:" : "Se actualizarán las siguientes apps:",
    "These incompatible apps will be disabled:" : "Estas aplicaciones incompatibles serán deshabilitadas:",
    "The theme %s has been disabled." : "El tema %s ha sido desactivado.",
    "Please make sure that the database, the config folder and the data folder have been backed up before proceeding." : "Antes de proceder, asegúrese de que se haya hecho un respaldo de la base de datos, la carpeta de configuración y la carpeta de datos.",
    "Start update" : "Iniciar actualización",
    "To avoid timeouts with larger installations, you can instead run the following command from your installation directory:" : "Para evitar tiempos de espera en grandes instalaciones, en su lugar puede ejecutar el siguiente comando desde el directorio de instalación:",
    "Detailed logs" : "Registros detallados",
    "Update needed" : "Se necesita actualización",
    "Please use the command line updater because you have a big instance with more than 50 accounts." : "Por favor, use el actualizador de línea de comandos ya que tiene una gran instancia con más de 50 cuentas.",
    "For help, see the  <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%s\">documentation</a>." : "Para obtener ayuda, consulta la <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%s\">documentación</a>.",
    "I know that if I continue doing the update via web UI has the risk, that the request runs into a timeout and could cause data loss, but I have a backup and know how to restore my instance in case of a failure." : "Sé que si continúo haciendo la actualización a través de la interfaz web, tengo el riesgo de que la solicitud no se ejecute en el tiempo de espera y provoque pérdida de información pero tengo una copia de seguridad de los datos y sé como restaurarla.",
    "Upgrade via web on my own risk" : "Actualizar a través de la web con mi consentimiento.",
    "Maintenance mode" : "Modo mantenimiento",
    "This %s instance is currently in maintenance mode, which may take a while." : "Está instancia %s está en modo mantenimiento, y puede tardar un rato.",
    "This page will refresh itself when the instance is available again." : "Esta página se actualizará sola cuando la instancia esté disponible de nuevo.",
    "Contact your system administrator if this message persists or appeared unexpectedly." : "Contacte con su administrador de sistemas si este mensaje persiste o aparece de forma inesperada.",
    "Currently open" : "Actualmente abierto",
    "Login with username or email" : "Iniciar sesión con nombre de usuario o correo electrónico",
    "Login with username" : "Iniciar sesión con nombre de usuario",
    "Chatting, video calls, screensharing, online meetings and web conferencing – in your browser and with mobile apps." : "Mensajes, videollamadas, compartir pantalla, reuniones online y conferencias web – en tu navegador y con apps móviles.",
    "You have not added any info yet" : "Aún no has añadido nada de información",
    "{user} has not added any info yet" : "{user} no ha añadido aún nada de información",
    "Error opening the user status modal, try hard refreshing the page" : "Error al abrir la ventana de estado del usuario, intente actualizar la página",
    "Edit Profile" : "Editar perfil",
    "The headline and about sections will show up here" : "El título y la sección acerca de aparecerán aquí",
    "Error loading message template: {error}" : "Error al cargar plantilla del mensaje: {error}",
    "Very weak password" : "Contraseña muy débil",
    "Weak password" : "Contraseña débil",
    "So-so password" : "Contraseña normal",
    "Good password" : "Contraseña buena",
    "Strong password" : "Contraseña muy buena",
    "Profile not found" : "Perfil no encontrado",
    "The profile does not exist." : "El perfil no existe.",
    "Your data directory and files are probably accessible from the internet because the .htaccess file does not work." : "Su directorio de datos y sus archivos probablemente sean accesibles a través de internet ya que el archivo .htaccess no funciona.",
    "For information how to properly configure your server, please see the <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">documentation</a>." : "Para información sobre cómo configurar adecuadamente el servidor, revisa por favor la <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">documentación</a>.",
    "<strong>Create an admin account</strong>" : "Crear una <strong>cuenta de administrador</strong>",
    "New admin account name" : "Nuevo nombre para la cuenta de administrador",
    "New admin password" : "Nueva contraseña de administrador",
    "Show password" : "Mostrar contraseña",
    "Toggle password visibility" : "Alternar visibilidad de la contraseña",
    "Configure the database" : "Configurar la base de datos",
    "Only %s is available." : "Solo %s está disponible.",
    "Database account" : "Cuenta de la base de datos"
},
"nplurals=3; plural=n == 1 ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
